.. kooplearn documentation master file, created by
   sphinx-quickstart on Sat Jan 14 15:52:00 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to kooplearn's documentation!
=====================================

.. toctree::
   :maxdepth: 2
   :caption: *INTRODUCTION*
   installation
   kooplearn


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
